import re
import os
from pathlib import Path

# Function to read and process .po file
def process_po_file(file_name):
	try:
		with open(file_name, "r") as file:
			content = file.read()

			entries = re.findall(r"(msgctxt\s+\".+?\"\nmsgid\s+\".+?\"\nmsgstr\s+\".+?\")", content, re.DOTALL)

			result = []
			for entry in entries:
				lines = entry.split("\n")
				msgctxt_line = lines[0]
				msgid_lines = [line for line in lines if line.startswith("msgid")]
				msgstr_lines = [line for line in lines if line.startswith("msgstr")]

				msgctxt = re.findall(r"msgctxt\s+\"(.+?)\"", msgctxt_line)[0]
				msgid = " ".join(re.findall(r"msgid\s+\"(.+?)\"", "\n".join(msgid_lines)))
				msgstr = " ".join(re.findall(r"msgstr\s+\"(.+?)\"", "\n".join(msgstr_lines)))

				result.append({"msgctxt": msgctxt, "msgid": msgid, "msgstr": msgstr})

		return result
	except Exception as e:
		print(f"Process_po_file Exception {e} in {file_name} {msgctxt_line}")
		quit()

# Function to create .lex file
def create_lex_file(translations, lex_file_name):
    with open(lex_file_name, "w") as file:
        for translation in translations:
            file.write(f"'{translation['msgctxt']}' => '{translation['msgstr']}',\n")

# Main program
SOURCE_BASE_DIR = Path("/home/brianr/Documents/smeserver-manager-locale/root/usr/share/smanager/lib/SrvMngr/I18N/Modules")

# Iterate over subdirectories in SOURCE_BASE_DIR
for subdir in [subdir.path for subdir in os.scandir(SOURCE_BASE_DIR) if subdir.is_dir()]:
	module_name = Path(subdir).name
	print(f"Processing {module_name}")
	po_dir = Path(os.path.join(subdir, "pofiles"))
	#print(po_dir)
	lex_dir = Path(os.path.join(subdir, "newlex"))
	#print(lex_dir)
	# Ensure the newlex directory exists
	lex_dir.mkdir(parents=True, exist_ok=True)

	for file in os.listdir(po_dir):
		if file.endswith(".po"):
			po_file_path = Path(os.path.join(po_dir, file))
			translations = process_po_file(po_file_path)
			lex_file_name = lex_dir / (po_file_path.stem + ".lex")
			create_lex_file(translations, lex_file_name)
